@@ -335,6 +335,46 @@ def dump_template_fields(_json):
     set_if_not_equal(result, "script_ext_windows", _json["scriptTypeWindows"], None)
     return result
 
+def dump_events(events_json):
+    events = []
+    for event in events_json:
+        result = {}
+        set_if_not_equal(result, "name", event["name"], None)
+        set_if_not_equal(result, "label", event["label"], None)
+        set_if_not_equal(result, "sys_id", event["sysId"], None)
+        set_if_not_equal(result, "description", event["description"], None)
+        set_if_not_equal(result, "policy", event["attributesPolicy"], None)
+        set_if_not_equal(result, "ttl", event["ttl"], 60)
+        result["attributes"] = []
+        print(event["attributes"])
+        for _attr in event["attributes"]:
+            attr_result = { _attr["name"]: _attr["type"] }
+            set_if_not_equal(result, "label", _attr["label"], labelize(_attr["name"]))
+            result["attributes"].append(attr_result)
+        events.append(result)
+
+    return events
+
+def prepare_event_fields(events):
+    result = []
+    for event in events:
+        _dict = {}
+        _dict["name"] = event.get("name")
+        _dict["label"] = event.get("label", None)
+        _dict["sysId"] = event.get("sys_id", new_uuid())
+        _dict["ttl"] = event.get("ttl", 60)
+        _dict["description"] = event.get("description", None)
+        _dict["attributesPolicy"] = event.get("attributesPolicy", "Include Attributes")
+        _dict["attributes"] = []
+        for _attr in event["attributes"]:
+            name = list(_attr.keys())[0]
+            type = list(_attr.values())[0]
+            label = _attr.get("label", labelize(name))
+            _dict["attributes"].append({"name": name, "label": label, "type": type})
+        result.append(_dict)
+
+    return result
+
 
 def new_uuid():
     return str(uuid.uuid4()).replace("-","")
